Support
=======

If you have questions or need help with testinfra please consider one of the
following

Issue Tracker
~~~~~~~~~~~~~

Checkout existing issues on `project issue tracker <https://github.com/pytest-dev/pytest-testinfra/issues>`_

IRC
~~~

You can also ask questions on IRC in `#pytest <https://web.libera.chat/?channel=#pytest>`_ channel on [libera.chat](https://libera.chat/) network.

pytest documentation
~~~~~~~~~~~~~~~~~~~~

testinfra is implemented as pytest plugin so to get the most out of please
read `pytest documentation <https://docs.pytest.org/en/latest/>`_

Community Contributions
~~~~~~~~~~~~~~~~~~~~~~~

* `Molecule <https://molecule.readthedocs.io>`_ is an Automated testing framework for Ansible roles, with native Testinfra support.
